@@ -1,6 +1,6 @@
 use anyhow::Result;
 use log::LevelFilter;
-use metrics_datadog_exporter::builder::DataDogBuilder;
+use metrics_datadog_exporter::DataDogBuilder;
 use metrics_macros::{counter, gauge, histogram};
 
 #[tokio::main(flavor = "current_thread")]
