@@ -1,6 +1,7 @@
 use anyhow::Result;
-use metrics_datadog_exporter::builder::DataDogBuilder;
-use metrics_datadog_exporter::data::{DataDogMetric, DataDogMetricType, DataDogMetricValue};
+use metrics_datadog_exporter::{
+    DataDogBuilder, DataDogMetric, DataDogMetricType, DataDogMetricValue,
+};
 use metrics_macros::{counter, gauge, histogram};
 use std::collections::HashMap;
 
@@ -22,7 +23,7 @@ fn collect_test() -> Result<()> {
     assert_eq!(counter.tags, vec!["tag2:value2".to_string()]);
     assert_eq!(counter.points, vec![DataDogMetricValue::Int(123)]);
     let histogram = collected.get("this.histogram").unwrap();
-    assert_eq!(histogram.metric_type, DataDogMetricType::Count);
+    assert_eq!(histogram.metric_type, DataDogMetricType::Histogram);
     assert_eq!(histogram.points.len(), 2);
     Ok(())
 }
